@@ -3,19 +3,15 @@ import nonebot.adapters.onebot.v11
 from loguru import logger
 from nonebot import on_command, on_message, get_driver
 from nonebot.params import CommandArg
+from nonebot.permission import SUPERUSER
 from nonebot.adapters.onebot.v11 import Message, MessageSegment,MessageEvent,Bot,ActionFailed,GroupMessageEvent,PrivateMessageEvent
 from nonebot_plugin_guild_patch import GuildMessageEvent
 from nonebot.log import logger
-from .publicAPI import get_nation_list,get_ship_name,get_ship_byName
-from .wws_info import get_AccountInfo
-from .wws_recent import get_RecentInfo
-from .wws_bind import set_BindInfo,get_BindInfo,change_BindInfo,set_special_BindInfo,delete_BindInfo
-from .wws_ship import get_ShipInfo,get_ShipInfoRecent,ShipSecletProcess
-from .wws_clan import get_ClanInfo,ClanSecletProcess
-from .wws_record import get_record
-from .wws_shiprank import get_ShipRank
-from .data_source import command_list
-from .utils import find_and_replace_keywords,DailyNumberLimiter,FreqLimiter,get_bot
+from .wws_ship import ShipSecletProcess
+from .wws_clan import ClanSecletProcess
+from .utils import DailyNumberLimiter,FreqLimiter,get_bot,download
+from .data_source import nb2_file
+from .command_select import select_command
 from nonebot_plugin_htmlrender import text_to_pic
 from pathlib import Path
 import httpx
@@ -23,6 +19,9 @@ import json
 import asyncio
 import re
 import html
+import os
+import platform
+import sys
 from nonebot import require
 scheduler = require("nonebot_plugin_apscheduler").scheduler
 
@@ -30,17 +29,18 @@ _max = 100
 EXCEED_NOTICE = f'您今天已经冲过{_max}次了，请明早5点后再来！'
 _nlmt = DailyNumberLimiter(_max)
 _flmt = FreqLimiter(3)
-__version__ = '0.3.3.2'
+__version__ = '0.3.3.3'
 dir_path = Path(__file__).parent
 template_path = dir_path / "template"
 
 bot = on_command("wws", block=False, aliases={"WWS"},priority=5)
+bot_checkversion = on_command("wws 检查更新",priority=5,block=True)
+bot_update = on_command("wws 更新Hikari",priority=5,block=True,permission=SUPERUSER)
 bot_listen = on_message(priority=5,block=False)
-bot_checkversion = on_command("wws 检查更新",priority=5,block=False)
 driver = get_driver()
 
 @bot.handle()
-async def selet_command(bot:Bot, ev:MessageEvent, matchmsg: Message = CommandArg()):
+async def main(bot:Bot, ev:MessageEvent, matchmsg: Message = CommandArg()):
     try:
         server_type = None
         if isinstance(ev, PrivateMessageEvent) and (driver.config.private or str(ev.user_id) in driver.config.superusers):       #私聊事件,superusers默认不受影响
@@ -56,7 +56,7 @@ async def selet_command(bot:Bot, ev:MessageEvent, matchmsg: Message = CommandArg
             return
         msg = ''
         qqid = ev.user_id
-        select_command,replace_name = None,None
+        replace_name = None
         if not _nlmt.check(qqid):
             await bot.send(ev,EXCEED_NOTICE, at_sender=True)
             return
@@ -69,75 +69,20 @@ async def selet_command(bot:Bot, ev:MessageEvent, matchmsg: Message = CommandArg
         if not searchtag:
             await bot.send(ev,"请发送wws help查看相关帮助")
             return
+        if searchtag == 'help':
+            msg = await send_bot_help()
+            await bot.send(ev,MessageSegment.image(msg))
+            return
         match = re.search(r"(\(|（)(.*?)(\)|）)",searchtag)
         if match:
             replace_name = match.group(2)
             search_list = searchtag.replace(match.group(0),'').split()
         else:
             search_list = searchtag.split()
-        select_command,search_list = await find_and_replace_keywords(search_list,command_list)
-        if not select_command:
-            if replace_name:
-                search_list.append(replace_name)
-            msg = await get_AccountInfo(server_type,qqid,search_list)
-        elif select_command == 'ship':
-            select_command = None
-            select_command,search_list = await find_and_replace_keywords(search_list,command_list)         #第二次匹配
-            if replace_name:
-                search_list.append(replace_name)
-            if not select_command:
-                msg = await get_ShipInfo(server_type,qqid,search_list,ev)
-            elif select_command == 'recent':
-                msg = await get_ShipInfoRecent(server_type,qqid,search_list,ev)
-            else:
-                msg = '看不懂指令QAQ'
-        elif select_command == 'recent':
-            select_command = None
-            select_command,search_list = await find_and_replace_keywords(search_list,command_list)             #第二次匹配
-            if replace_name:
-                search_list.append(replace_name)
-            if not select_command:
-                msg = await get_RecentInfo(server_type,qqid,search_list)
-            elif select_command == 'ship':
-                msg = await get_ShipInfoRecent(server_type,qqid,search_list,ev)
-            else:
-                msg = '看不懂指令QAQ'
-        elif select_command == 'clan':
-            select_command = None
-            select_command,search_list = await find_and_replace_keywords(search_list,command_list) 
-            if not select_command:                  #查询公会详情信息
-                msg = await get_ClanInfo(server_type,qqid,search_list,ev)
-            elif select_command == 'record':        #查询公会历史记录
-                msg = await get_record(server_type,qqid,search_list,"clan")
-        elif select_command == 'record':
-            select_command = None
-            select_command,search_list = await find_and_replace_keywords(search_list,command_list) 
-            if replace_name:
-                search_list.append(replace_name)
-            if not select_command:                  #查询个人历史记录
-                msg = await get_record(server_type,qqid,search_list,"personal")
-            elif select_command == 'clan':          #查询公会历史记录
-                msg = await get_record(server_type,qqid,search_list,"clan")
-        elif select_command == 'ship_rank':
-            msg = await get_ShipRank(qqid,search_list,ev)   
-        elif select_command == 'bind':
-            if replace_name:
-                search_list.append(replace_name)
-            msg = await set_BindInfo(server_type,qqid,search_list)
-        elif select_command == 'special_bind':
-            msg = await set_special_BindInfo(server_type,qqid,search_list)
-        elif select_command == 'bindlist':
-            msg = await get_BindInfo(server_type,qqid,search_list)
-        elif select_command == 'changebind':
-            msg = await change_BindInfo(server_type,qqid,search_list)
-        elif select_command == 'delete_bind':
-            msg = await delete_BindInfo(server_type,qqid,search_list)
-        elif select_command == 'searchship':
-            msg = await get_ship_name(search_list)
-        elif select_command == 'help':
-            msg = await send_bot_help()
-        else:
-            msg = '看不懂指令QAQ'
+        command,search_list = await select_command(search_list)
+        if replace_name:
+            search_list.append(replace_name)
+        msg = await command(server_type,search_list,bot,ev)
         if msg:
             if isinstance(msg,str):
                 await bot.send(ev,msg)
@@ -146,7 +91,7 @@ async def selet_command(bot:Bot, ev:MessageEvent, matchmsg: Message = CommandArg
                 await bot.send(ev,MessageSegment.image(msg))
                 return
         else:
-            await bot.send(ev,'呜呜呜发生了错误，可能是网络问题，如果过段时间不能恢复请联系麻麻哦~')
+            await bot.send(ev,'没有获取到数据，可能是内部问题')
             return
     except ActionFailed:
         logger.warning(traceback.format_exc())
@@ -158,7 +103,7 @@ async def selet_command(bot:Bot, ev:MessageEvent, matchmsg: Message = CommandArg
     except Exception:
         logger.error(traceback.format_exc())
         await bot.send(ev,'呜呜呜发生了错误，可能是网络问题，如果过段时间不能恢复请联系麻麻哦~')
-                
+             
 async def send_bot_help():
     try:
         url = 'https://benx1n.oss-cn-beijing.aliyuncs.com/version.json'
@@ -199,6 +144,38 @@ async def change_select_state(ev:MessageEvent):
         logger.warning(traceback.format_exc())
         return
 
+@bot_update.handle()
+async def update_Hikari(ev:MessageEvent,bot:Bot):
+    try:
+        from nonebot_plugin_reboot import Reloader
+        await bot.send(ev,'正在更新Hikari，完成后将自动重启，如果没有回复您已上线的消息，请登录服务器查看')
+        if hasattr(driver.config,'nb2_path'):
+            await asyncio.gather(*[download(
+                each['url'],
+                f"{driver.config.nb2_path}\{each['name']}"
+                ) for each in nb2_file])
+        os.system(f'python -m pip install --upgrade hikari-bot')
+        os.system(f'python -m pip install --upgrade nonebot-plugin-gocqhttp')
+        Reloader.reload(delay=1)
+    except RuntimeError:
+        if str(platform.system()).lower() == 'linux':
+            try:
+                import multiprocessing
+                for child in multiprocessing.active_children():
+                    child.terminate()
+                sys.stdout.flush()
+                #not compatible with cmdline with '\n' 
+                os.execv(os.readlink('/proc/self/exe'), open('/proc/self/cmdline', 'rb').read().replace(b'\0', b'\n').decode().split('\n')[:-1])
+            except Exception:
+                logger.error(traceback.format_exc())
+                await bot.send(ev,'自动更新失败了QAQ，请登录服务器查看具体报错日志')
+        else:
+            logger.error(traceback.format_exc())
+            await bot.send(ev,'不支持nb run启动的方式更新哦，请使用python bot.py 启动Hikari')
+    except Exception:
+        logger.error(traceback.format_exc())
+        await bot.send(ev,'自动更新失败了QAQ，请登录服务器查看具体报错日志')
+
 @bot_checkversion.handle()
 async def check_version():
     try:
@@ -207,7 +184,7 @@ async def check_version():
         async with httpx.AsyncClient() as client:
             resp = await client.get(url, timeout=10)
             result = json.loads(resp.text)
-        superid = get_driver().config.superusers
+        superid = driver.config.superusers
         match,msg = False,f'发现新版本'
         for each in result['data']:
             if each['version'] > __version__:
@@ -250,7 +227,13 @@ async def startup():
     except Exception:
         logger.error(traceback.format_exc())
         return   
-     
+    
+@driver.on_bot_connect
+async def remind(bot: Bot):
+    superid = driver.config.superusers
+    for each in superid:
+        await bot.send_private_msg(user_id=int(each),message='Hikari已上线')
+
 async def startup_download(url,name):
     async with httpx.AsyncClient() as client:
         resp = resp = await client.get(url, timeout=20)
@@ -266,4 +249,4 @@ scheduler.add_job(
     startup,
     "cron",
     hour = 4
-)
\ No newline at end of file
+)
